@@ -12,3 +12,7 @@ config() {
 
 config etc/ntp.conf.new
 config etc/ntp/ntp.keys.new
+if [ -r etc/rc.d/rc.ntpd -a -r etc/rc.d/rc.ntpd.new ]; then
+  chmod --reference=etc/rc.d/rc.ntpd etc/rc.d/rc.ntpd.new
+fi
+config etc/rc.d/rc.ntpd.new
